module_path_without_crate

Macro module_path_without_crate 

macro_rules! module_path_without_crate {
    () => { ... };
}
Expands to the current module path without the crate name.

This behaves like module_path!, but removes the leading crate segment.

Panics

Panics if invoked from the crate root, because module_path! expands to just the crate name there, which does not contain "::".