KeyedLazyLock

Struct KeyedLazyLock 

pub struct KeyedLazyLock<K, V, F = fn(&K) -> V> { /* private fields */ }
Lazily initializes values per key.

The first call to KeyedLazyLock::get for a key creates the value using init. Later calls return the same value.

Initialization for each key happens at most once.

Implementations

Source

impl<K, V, F> KeyedLazyLock<K, V, F>

pub const fn new(init: F) -> Self

Source

impl<K, V, F> KeyedLazyLock<K, V, F>
where K: Eq + Hash + Clone, F: Fn(&K) -> V,

pub fn get(&self, key: &K) -> &V

Returns the lazily initialized value for key.

If the key has not been accessed before, init(key) will run exactly once. Concurrent callers requesting the same key will wait for initialization.

Deadlocks

init must not call get with the same key.