pub struct Location { /* private fields */ }Expand description
A serializable source code location.
This is meant to be a drop in replacement for std::panic::Location
with the added benefit that it implements Serialize and Deserialize.
In practice, this is useful when you want to capture caller information and store it, send it across process boundaries, or include it in serialized data.
For behavior and semantics, see std::panic::Location.
Implementations
Sourceimpl Location
impl Location
Sourcepub const fn caller() -> Self
pub const fn caller() -> Self
Returns the caller location.
See std::panic::Location::caller for details.
Sourcepub const fn file(&self) -> &str
pub const fn file(&self) -> &str
Returns the file name.
See std::panic::Location::file for details.
Sourcepub const fn column(&self) -> u32
pub const fn column(&self) -> u32
Returns the column number.
See std::panic::Location::column for details.
Sourcepub const fn line(&self) -> u32
pub const fn line(&self) -> u32
Returns the line number.
See std::panic::Location::line for details.