pub struct FmtHandle<W>(/* private fields */);Expand description
A cloneable handle to a single-threaded fmt writer.
Clones of this handle write to the same underlying writer. This type uses interior mutability and is not thread-safe, i.e. it is not Send nor Sync.
Example
use std::fmt::Write;
use nu_utils::FmtHandle;
let mut string = String::new();
let mut a = FmtHandle::new(&mut string);
let mut b = a.clone();
a.write_str("abc").unwrap();
b.write_str("def").unwrap();
drop(a);
drop(b);
assert_eq!(string, "abcdef");Implementations